==> LMGene_2.6.0.zip: LMGene/doc/LMGene.R <==
###################################################
### chunk number 1: 
###################################################
#line 50 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmprjnolu/R.INSTALL3d9e269e/LMGene/inst/doc/LMGene.Rnw"
library(LMGene)
library(Biobase)
library(tools)


###################################################
### chunk number 2: 
###################################################
#line 57 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmprjnolu/R.INSTALL3d9e269e/LMGene/inst/doc/LMGene.Rnw"
data(sample.eS)


###################################################
### chunk number 3: 
###################################################
#line 63 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmprjnolu/R.INSTALL3d9e269e/LMGene/inst/doc/LMGene.Rnw"
slotNames(sample.eS)
dim(exprs(sample.eS))
exprs(sample.eS)[1:3,]
phenoData(sample.eS)
slotNames(phenoData(sample.eS))


###################################################
### chunk number 4: 
###################################################
#line 80 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmprjnolu/R.INSTALL3d9e269e/LMGene/inst/doc/LMGene.Rnw"
data(sample.mat)
dim(sample.mat)
data(vlist)  
vlist


###################################################
### chunk number 5: 
###################################################
#line 88 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmprjnolu/R.INSTALL3d9e269e/LMGene/inst/doc/LMGene.Rnw"
test.eS<-neweS(sample.mat, vlist)
class(test.eS)


###################################################
### chunk number 6: 
###################################################
#line 104 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmprjnolu/R.INSTALL3d9e269e/LMGene/inst/doc/LMGene.Rnw"
tranpar <- tranest(sample.eS)
tranpar


###################################################
### chunk number 7: 
###################################################
#line 113 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmprjnolu/R.INSTALL3d9e269e/LMGene/inst/doc/LMGene.Rnw"
tranpar <- tranest(sample.eS, 100)
tranpar


###################################################
### chunk number 8: 
###################################################
#line 125 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmprjnolu/R.INSTALL3d9e269e/LMGene/inst/doc/LMGene.Rnw"

trsample.eS <- transeS(sample.eS, tranpar$lambda, tranpar$alpha)
exprs(sample.eS)[1:3,1:8]
exprs(trsample.eS)[1:3,1:8]


###################################################
### chunk number 9: 
###################################################
#line 137 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmprjnolu/R.INSTALL3d9e269e/LMGene/inst/doc/LMGene.Rnw"
tranparmult <- tranest(sample.eS, mult=TRUE) 
tranparmult


###################################################
### chunk number 10: 
###################################################
#line 144 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmprjnolu/R.INSTALL3d9e269e/LMGene/inst/doc/LMGene.Rnw"
trsample.eS <- transeS (sample.eS, tranparmult$lambda, tranparmult$alpha)
exprs(trsample.eS)[1:3,1:8]


###################################################
### chunk number 11: 
###################################################
#line 151 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmprjnolu/R.INSTALL3d9e269e/LMGene/inst/doc/LMGene.Rnw"
tranparmult <- tranest(sample.eS, ngenes=100, mult=TRUE, lowessnorm=TRUE) 
tranparmult


###################################################
### chunk number 12: 
###################################################
#line 159 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmprjnolu/R.INSTALL3d9e269e/LMGene/inst/doc/LMGene.Rnw"
tranpar <- tranest(sample.eS, model='patient + dose + patient:dose')
tranpar


###################################################
### chunk number 13: 
###################################################
#line 179 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmprjnolu/R.INSTALL3d9e269e/LMGene/inst/doc/LMGene.Rnw"
trsample.eS <- transeS (sample.eS, tranparmult$lambda, tranparmult$alpha)
ntrsample.eS <- lnormeS (trsample.eS) 


###################################################
### chunk number 14: 
###################################################
#line 187 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmprjnolu/R.INSTALL3d9e269e/LMGene/inst/doc/LMGene.Rnw"
sigprobes <- LMGene(ntrsample.eS)


###################################################
### chunk number 15: 
###################################################
#line 193 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmprjnolu/R.INSTALL3d9e269e/LMGene/inst/doc/LMGene.Rnw"
sigprobes <- LMGene(ntrsample.eS,level=.01)


###################################################
### chunk number 16: 
###################################################
#line 203 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmprjnolu/R.INSTALL3d9e269e/LMGene/inst/doc/LMGene.Rnw"
sigprobes <- LMGene(ntrsample.eS, model='patient+dose+patient:dose')
sigprobes

==> LMGene_2.8.0.zip: LMGene/doc/LMGene.R <==
###################################################
### chunk number 1: 
###################################################
#line 50 "LMGene.Rnw"
library(LMGene)
library(Biobase)
library(tools)


###################################################
### chunk number 2: 
###################################################
#line 57 "LMGene.Rnw"
data(sample.eS)


###################################################
### chunk number 3: 
###################################################
#line 63 "LMGene.Rnw"
slotNames(sample.eS)
dim(exprs(sample.eS))
exprs(sample.eS)[1:3,]
phenoData(sample.eS)
slotNames(phenoData(sample.eS))


###################################################
### chunk number 4: 
###################################################
#line 80 "LMGene.Rnw"
data(sample.mat)
dim(sample.mat)
data(vlist)  
vlist


###################################################
### chunk number 5: 
###################################################
#line 88 "LMGene.Rnw"
test.eS<-neweS(sample.mat, vlist)
class(test.eS)


###################################################
### chunk number 6: 
###################################################
#line 104 "LMGene.Rnw"
tranpar <- tranest(sample.eS)
tranpar


###################################################
### chunk number 7: 
###################################################
#line 113 "LMGene.Rnw"
tranpar <- tranest(sample.eS, 100)
tranpar


###################################################
### chunk number 8: 
###################################################
#line 125 "LMGene.Rnw"

trsample.eS <- transeS(sample.eS, tranpar$lambda, tranpar$alpha)
exprs(sample.eS)[1:3,1:8]
exprs(trsample.eS)[1:3,1:8]


###################################################
### chunk number 9: 
###################################################
#line 137 "LMGene.Rnw"
tranparmult <- tranest(sample.eS, mult=TRUE) 
tranparmult


###################################################
### chunk number 10: 
###################################################
#line 144 "LMGene.Rnw"
trsample.eS <- transeS (sample.eS, tranparmult$lambda, tranparmult$alpha)
exprs(trsample.eS)[1:3,1:8]


###################################################
### chunk number 11: 
###################################################
#line 151 "LMGene.Rnw"
tranparmult <- tranest(sample.eS, ngenes=100, mult=TRUE, lowessnorm=TRUE) 
tranparmult


###################################################
### chunk number 12: 
###################################################
#line 159 "LMGene.Rnw"
tranpar <- tranest(sample.eS, model='patient + dose + patient:dose')
tranpar


###################################################
### chunk number 13: 
###################################################
#line 179 "LMGene.Rnw"
trsample.eS <- transeS (sample.eS, tranparmult$lambda, tranparmult$alpha)
ntrsample.eS <- lnormeS (trsample.eS) 


###################################################
### chunk number 14: 
###################################################
#line 187 "LMGene.Rnw"
sigprobes <- LMGene(ntrsample.eS)


###################################################
### chunk number 15: 
###################################################
#line 193 "LMGene.Rnw"
sigprobes <- LMGene(ntrsample.eS,level=.01)


###################################################
### chunk number 16: 
###################################################
#line 203 "LMGene.Rnw"
sigprobes <- LMGene(ntrsample.eS, model='patient+dose+patient:dose')
sigprobes
